Documentation
¶
Overview ¶
Package v1 contains API Schema definitions for the requeueip v1 API group.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects. GroupVersion = schema.GroupVersion{Group: consts.RAPIGroup, Version: consts.RAPIVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme. SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type BlockCount ¶
type BlockCount struct {
// Total is the total number of IP blocks in the Subnet.
Total string `json:"total"`
// Used is the number of used IP blocks in the Subnet.
Used string `json:"used"`
// Free is the number of available IP blocks in the Subnet.
Free string `json:"free"`
}
BlockCount represents the IP block count status of Subnet.
func (*BlockCount) DeepCopy ¶
func (in *BlockCount) DeepCopy() *BlockCount
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BlockCount.
func (*BlockCount) DeepCopyInto ¶
func (in *BlockCount) DeepCopyInto(out *BlockCount)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Count ¶
type Count struct {
// Total is the total number of IP addresses in the IPPool.
Total string `json:"total"`
// Used is the number of used IP addresses in the IPPool.
Used string `json:"used"`
// Free is the number of available IP addresses in the IPPool.
Free string `json:"free"`
}
Count represents the count status of IPPool.
func (*Count) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Count.
func (*Count) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IP ¶
type IP struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
}
IP is the Schema for the IPs API.
func (*IP) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IP.
func (*IP) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IP) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type IPBlock ¶
type IPBlock struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
}
IPBlock is the Schema for the IPBlocks API.
func (*IPBlock) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPBlock.
func (*IPBlock) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IPBlock) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type IPBlockList ¶
type IPBlockList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []IPBlock `json:"items"`
}
IPBlockList contains a list of IPBlock.
func (*IPBlockList) DeepCopy ¶
func (in *IPBlockList) DeepCopy() *IPBlockList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPBlockList.
func (*IPBlockList) DeepCopyInto ¶
func (in *IPBlockList) DeepCopyInto(out *IPBlockList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IPBlockList) DeepCopyObject ¶
func (in *IPBlockList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type IPList ¶
type IPList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []IP `json:"items"`
}
IPList contains a list of IP.
func (*IPList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPList.
func (*IPList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IPList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type IPPool ¶
type IPPool struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec IPPoolSpec `json:"spec,omitempty"`
Status IPPoolStatus `json:"status,omitempty"`
}
IPPool is the Schema for the IPPools API.
func (*IPPool) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPPool.
func (*IPPool) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IPPool) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type IPPoolClaim ¶
type IPPoolClaim struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec IPPoolClaimSpec `json:"spec,omitempty"`
Status IPPoolClaimStatus `json:"status,omitempty"`
}
IPPoolClaim is the Schema for the IPPoolClaims API.
func (*IPPoolClaim) DeepCopy ¶
func (in *IPPoolClaim) DeepCopy() *IPPoolClaim
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPPoolClaim.
func (*IPPoolClaim) DeepCopyInto ¶
func (in *IPPoolClaim) DeepCopyInto(out *IPPoolClaim)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IPPoolClaim) DeepCopyObject ¶
func (in *IPPoolClaim) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type IPPoolClaimList ¶
type IPPoolClaimList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []IPPoolClaim `json:"items"`
}
IPPoolClaimList contains a list of IPPoolClaim.
func (*IPPoolClaimList) DeepCopy ¶
func (in *IPPoolClaimList) DeepCopy() *IPPoolClaimList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPPoolClaimList.
func (*IPPoolClaimList) DeepCopyInto ¶
func (in *IPPoolClaimList) DeepCopyInto(out *IPPoolClaimList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IPPoolClaimList) DeepCopyObject ¶
func (in *IPPoolClaimList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type IPPoolClaimSpec ¶
type IPPoolClaimSpec struct {
// Version specifies the IP version (IPv4 or IPv6) for the IPPool.
Version string `json:"version"`
// Subnets is a list of candidate Subnet names for IP address assignments.
Subnets []string `json:"subnets"`
// Replicas specifies the number of IP addresses to reserve from the selected
// Subnet. An IPPool of this size will be created based on this claim.
Replicas int32 `json:"replicas"`
}
IPPoolClaimSpec defines the desired state of IPPoolClaim.
func (*IPPoolClaimSpec) DeepCopy ¶
func (in *IPPoolClaimSpec) DeepCopy() *IPPoolClaimSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPPoolClaimSpec.
func (*IPPoolClaimSpec) DeepCopyInto ¶
func (in *IPPoolClaimSpec) DeepCopyInto(out *IPPoolClaimSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IPPoolClaimStatus ¶
type IPPoolClaimStatus struct {
// Subnet is the selected Subnet name from the candidate list.
Subnet *string `json:"subnet,omitempty"`
// PoolSize is the current size of the IPPool created based on the claim.
PoolSize *int32 `json:"poolSize,omitempty"`
}
IPPoolClaimStatus defines the observed state of IPPoolClaim.
func (*IPPoolClaimStatus) DeepCopy ¶
func (in *IPPoolClaimStatus) DeepCopy() *IPPoolClaimStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPPoolClaimStatus.
func (*IPPoolClaimStatus) DeepCopyInto ¶
func (in *IPPoolClaimStatus) DeepCopyInto(out *IPPoolClaimStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IPPoolList ¶
type IPPoolList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []IPPool `json:"items"`
}
IPPoolList contains a list of IPPool.
func (*IPPoolList) DeepCopy ¶
func (in *IPPoolList) DeepCopy() *IPPoolList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPPoolList.
func (*IPPoolList) DeepCopyInto ¶
func (in *IPPoolList) DeepCopyInto(out *IPPoolList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IPPoolList) DeepCopyObject ¶
func (in *IPPoolList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type IPPoolSpec ¶
type IPPoolSpec struct {
// Version specifies the IP version (IPv4 or IPv6) of the IPPool.
Version string `json:"version"`
// Subnet specifies the Subnet to which this IPPool belongs.
Subnet string `json:"subnet"`
// Ranges is the set of IP ranges allocated to this IPPool.
Ranges []string `json:"ranges"`
}
IPPoolSpec defines the desired state of IPPool.
func (*IPPoolSpec) DeepCopy ¶
func (in *IPPoolSpec) DeepCopy() *IPPoolSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPPoolSpec.
func (*IPPoolSpec) DeepCopyInto ¶
func (in *IPPoolSpec) DeepCopyInto(out *IPPoolSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IPPoolStatus ¶
type IPPoolStatus struct {
// Free is the current available IP ranges in the IPPool.
Free []string `json:"free"`
// Count is the count status of the IPPool.
Count *Count `json:"count,omitempty"`
}
IPPoolStatus defines the observed state of IPPool.
func (*IPPoolStatus) DeepCopy ¶
func (in *IPPoolStatus) DeepCopy() *IPPoolStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPPoolStatus.
func (*IPPoolStatus) DeepCopyInto ¶
func (in *IPPoolStatus) DeepCopyInto(out *IPPoolStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Subnet ¶
type Subnet struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec SubnetSpec `json:"spec,omitempty"`
Status SubnetStatus `json:"status,omitempty"`
}
Subnet is the Schema for the Subnets API.
func (*Subnet) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Subnet.
func (*Subnet) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Subnet) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type SubnetList ¶
type SubnetList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Subnet `json:"items"`
}
SubnetList contains a list of Subnet.
func (*SubnetList) DeepCopy ¶
func (in *SubnetList) DeepCopy() *SubnetList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SubnetList.
func (*SubnetList) DeepCopyInto ¶
func (in *SubnetList) DeepCopyInto(out *SubnetList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*SubnetList) DeepCopyObject ¶
func (in *SubnetList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type SubnetSpec ¶
type SubnetSpec struct {
// Version specifies the IP version (IPv4 or IPv6) of the Subnet.
Version *string `json:"version,omitempty"`
// CIDR specifies the CIDR notation of the Subnet.
CIDR string `json:"cidr"`
// Excluded is a list of IP ranges to exclude from the Subnet.
Excluded []string `json:"excluded,omitempty"`
// BlockSize specifies the minimum unit of IP address assignments from the
// Subnet. Defaults to 30 for IPv4 and 126 for IPv6.
BlockSize *int32 `json:"blockSize,omitempty"`
}
SubnetSpec defines the desired state of Subnet.
func (*SubnetSpec) DeepCopy ¶
func (in *SubnetSpec) DeepCopy() *SubnetSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SubnetSpec.
func (*SubnetSpec) DeepCopyInto ¶
func (in *SubnetSpec) DeepCopyInto(out *SubnetSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SubnetStatus ¶
type SubnetStatus struct {
// Free is the current available IP ranges in the Subnet.
Free []string `json:"free"`
// BlockCount is the IP block count status of the Subnet.
BlockCount *BlockCount `json:"blockCount,omitempty"`
}
SubnetStatus defines the observed state of Subnet.
func (*SubnetStatus) DeepCopy ¶
func (in *SubnetStatus) DeepCopy() *SubnetStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SubnetStatus.
func (*SubnetStatus) DeepCopyInto ¶
func (in *SubnetStatus) DeepCopyInto(out *SubnetStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.